CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
46 lines
1.2 KiB
C++
46 lines
1.2 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <vector>
|
|
#include <thread>
|
|
|
|
static void Copy_to_device() {
|
|
unsigned int ele_size = (32 * 1024); // 32KB
|
|
int* A_h = nullptr;
|
|
int* A_d = nullptr;
|
|
|
|
HIP_CHECK(hipHostMalloc(&A_h, ele_size * sizeof(int)));
|
|
HIP_CHECK(hipMalloc(&A_d, ele_size * sizeof(int)));
|
|
|
|
for (unsigned int i = 0; i < ele_size; ++i) {
|
|
A_h[i] = 123;
|
|
}
|
|
HIP_CHECK(
|
|
hipMemcpyAsync(A_d, A_h, ele_size * sizeof(int), hipMemcpyHostToDevice, hipStreamPerThread));
|
|
// Clean up
|
|
HIP_CHECK(hipHostFree(A_h));
|
|
HIP_CHECK(hipFree(A_d));
|
|
}
|
|
|
|
/*
|
|
hipStreamPerThread is an implicit stream which gets destroyed once thread is completed.
|
|
Scenario : App pushes Async task(s) into hipStreamPerThread and did not wait for it to complete.
|
|
Watch out : Incomplete task in hipStreamPerThread should not cause any crash due to thread exit.
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipStreamPerThread_MultiThread) {
|
|
constexpr unsigned int MAX_THREAD_CNT = 10;
|
|
std::vector<std::thread> threads(MAX_THREAD_CNT);
|
|
|
|
for (auto& th : threads) {
|
|
th = std::thread(Copy_to_device);
|
|
}
|
|
|
|
for (auto& th : threads) {
|
|
th.detach();
|
|
}
|
|
}
|